@@ -1,6 +1,7 @@
 /*********************************************
 * vim: set sw=8 ts=8 si :
 * Author: Guido Socher, Copyright: GPL 
+* Modified by: Nathanael Semhoun
 * This program is to test the led connected to
 * PC5 
 * See http://linuxfocus.org/English/March2003/
@@ -8,14 +9,13 @@
 * Chip type           : AT90S4433
 * Clock frequency     : 4,00 MHz
 *********************************************/
-#include <io.h>
-#include <progmem.h>
-#include <interrupt.h>
-#include <string-avr.h>
+#include <avr/io.h>
+#include <avr/pgmspace.h>
+#include <avr/interrupt.h>
+#include <string.h>
 #include <stdlib.h>
-#include <sig-avr.h>
 #include "avr-util.h" 
-
+#include "avr_compat.h"
 
 void main(void)
 {
