@@ -6,10 +6,10 @@
 ***************************************************************************/
 #ifndef UART_H
 #define UART_H
-#include <pgmspace.h>
+#include <avr/pgmspace.h>
 
 /* public result buffer len for uart_outbuf */ 
-#define UART_RX_BUFFER_SIZE 25
+#define UART_RX_BUFFER_SIZE 23
 
 extern void uart_init(void); /* call this function and then enable interrupt with sei() */
 extern void uart_sendchar(char c); /* send one char */
